@@ -1,6 +1,7 @@
 def list_chunks(mylist, n):
     """Yield successive n-sized chunks from mylist."""
-    return [mylist[i:i + n] for i in range(0, len(mylist), n)]
+    return [mylist[i : i + n] for i in range(0, len(mylist), n)]
+
 
 class JupyterPDF(object):
     """Class to display PDFs in a Jupyter / IPython notebook.
@@ -9,6 +10,7 @@ class JupyterPDF(object):
     >>> JupyterPDF("path_to_some.pdf")
     Credits to StackOverflow's Jakob: https://stackoverflow.com/a/19470377
     """
+
     def __init__(self, url, width=600, height=800):
         self.url = url
         self.width = width
@@ -20,4 +22,7 @@ class JupyterPDF(object):
                 <iframe src={self.url} width={self.width} height={self.height}>
                 </iframe>
             </center>
-        """.format(self=self)
\ No newline at end of file
+        """.format(
+            self=self
+        )
+
